# Cross-species cortical alignment identifies different types of neuroanatomical reorganization in the temporal lobe of higher primates

## Nicole Eichert, Emma C. Robinson, Katherine L. Bryant, Saad Jbabdi, Mark Jenkinson, Longchuan Li, Kristine Krug, Kate E. Watkins & Rogier B. Mars


The code provided demonstrates the processing steps for the analysis described in the paper.

## Myelin-based surface registration

### generate species average myelin maps

relevant script: `avg_myelin_species.sh`

This script demonstrates how the species average myelin maps in the right panel in Figure 2 were created. 

* resample individual maps of sulcal depth and cortical myelin to a common sphere (<1 min): `bash avg_myelin_species.sh --resample`
* create average species average map as initial referance image (<1 min): `bash avg_myelin_species.sh --avg0`
* Run MSMsulc for individual sulcal maps (5 min per subject): `bash avg_myelin_species.sh --MSMsulc`
* Run MSMmyelin for individual myelin maps using the MSMsulc-registration as initialization (5 min per subject): `bash avg_myelin_species.sh --MSMmyelin`
* Generate species avergae myelin map based on resampled, MSM-aligned maps (< 1 min): `bash avg_myelin_species.sh --avg1`

### MSM-derived registration
relevant script: `myelin_registration_MSM.sh`

This script demonstrates how the cross-species registration based on myelin maps in performed. 
The output of the registrations is shown in Figure 2. 

The different sections of the script are run consecutively. ROI-derived registration steps are derived prior to registration of the whole-hemisphere myelin maps. The 'step' in the section heading refers to the relevant cell in Table S2 (MSM configuration parameters). The last section of the script shows how the deformation map has been derived.

*Time required for each registration step: approx. 30 min.*

### Correlation of myelin maps
relevant script: `correlation_myelin_maps.m`

This script generates the local spatial maps of registered myelin map with reference myelin map for the registration steps.
The resulting correlation maps are shown in Appendix 2 - Figure 2.

*Time required: approx. 5 min.*

## Tract surface analysis

### Generate a whole-hemisphere connectivity matrix
relevant script: `create_connectivity_matrix.m`

A whole-hemisphere connectivity matrix is generated by tracking from each vertex to each brain voxel. Tractography using probtrack2 is called using quicktrack_gpu, which submits the task to a high-performance computing cluster.  

*Time required (on GPU)): approx. 1 h.*

### Correct connectivity matrix
relevant script: `correct_connectivity_matrix.m`

The connectivity matrix derived from the previous step is corrected using a vertex-by-voxel distance matrix. Each element in the connectivity matrix is divided by the respective element in the vertex-by-voxel matrix.

*Time required: approx. 1 h.*

### Average corrected connectivity matrices
relevant script: `average_connectivity_matrix.m`

Weighted connectivity matrices for each subject and hemisphere are averaged.

*Time required: approx. 1 h.*

### Perform Tractography
relevant script: `do_tractography.sh`

*Time required (on GPU): approx. 30 min per tract and subject.*

### group level tractography result.
relevant script: `process_tracts.sh`

The individual tracts are resampled, normalized and averaged using the this `process_tracts.sh`. 
Note that individual tractograms are used for further surface-based processing and not group level tractography results.

*Time required: approx. 10 min.*


### Generate Surface Tract Maps
relevant script: `generate_tract_map.m`

A surface tract map is generated by multiplication of the individual tractogram with the average corrected whole-brain connectivity matrix.



### Process tract maps and generate predicted tract map
relevant script: `process_surf_data.sh`

In this script the tract surface maps are processed including resampling, smoothing, logNorm transformation and averaging. 
The average chimpanzee and macaque tract maps are then transformed to human space by using the MSM registrations obtained above. 
The resulting maps in human space are thresholded and medial wall and insula are masked.

The final surface tract maps are shown in Figure 3 and in Appendix 3 - Figure 1.


*Time required: approx. 20 min.*


### Correlation maps and metrics
relevant script: `localcorr_dice_extension.m`

This script derives a weighted correlation map of the predicted chimpanzee or macaque tract map and the actual human tract map. Based on these maps we compute a Dice coefficient and tract extension ratio.
The final correlation maps are shown in Figure 4 and in Appendix 3 - Figure 1.

*Time required: approx. 20 min.*



### Plot of metric values
relevant script: `plot_metrics.py`

This script plots the Dice coefficient and tract extension metric and dice coefficient derived based on an area defined based on the thresholded actual human tract map.
The resulting plot is shown in Figure 5 and in Appendix 3 - Figure 2.


### Statistics
relevant scripts: `get_GLM.r`, `do_palm.py`

The model matrix for the GLM is generated in R using `get_GLM.r`. The model is fitted to the target metrics using palm in `do_palm.py`.

*Time required: approx. 2 h*


### Connectivity fingerpint
relevant scripts: `get_fingerprint.m`, `plot_fingerprint.py`

The connectivity fingerprint at two representative vertices is generated using get_fingrprint.m. The polar plot is generated in plot_fingerprint.py.
The result is shown in Figure 5.


*Time required: approx. 2 min*


### Quality Control
relevant scripts: `quality_control.sh`, `quality_control.py`

The dyad_dispersion and tract complexity measures in each subject are derived in the `.sh` script. 
In the corresponding `.py` script, these measures are loaded and correlated with the tract extension ratios.
The script also creates the plots shown in Appendix 4 - Figure 1.

*Time required: approx. 10 min*
